##
##  poppler.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         poppler
Summary:      PDF Rendering Library
URL:          http://poppler.freedesktop.org/
Vendor:       Derek Noonburg, Kristian Hagsberg
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        PLUS
Group:        Postscript
License:      GPL
Version:      24.12.0
Release:      20241206

#   package options
%option       with_svg    no
%option       with_crypto no

#   list of sources
Source0:      http://poppler.freedesktop.org/poppler-%{version}.tar.xz
Patch0:       poppler.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, gcc::with_cxx = yes, cmake
PreReq:       OpenPKG, openpkg >= 20160101, poppler-data
BuildPreReq:  cairo
PreReq:       cairo
%if "%{with_svg}" == "yes"
BuildPreReq:  cairo::with_svg = yes
PreReq:       cairo::with_svg = yes
%endif
BuildPreReq:  zstd, zlib, png, jpeg, tiff, openjpeg, freetype, fontconfig, lcms, curl, glib, boost
PreReq:       zstd, zlib, png, jpeg, tiff, openjpeg, freetype, fontconfig, lcms, curl, glib, boost
%if "%{with_crypto}" == "yes"
BuildPreReq:  gpgme
PreReq:       gpgme
%endif

%description
    Poppler is a fork of the PDF viewer XPDF code base, developed by
    Derek Noonburg of Glyph and Cog, LLC. The purpose is to provide PDF
    rendering functionality as a library.

%track
    prog poppler = {
        version   = %{version}
        url       = http://poppler.freedesktop.org/
        regex     = poppler-(__VER__)\.tar\.(gz|xz)
    }

%prep
    %setup -q
    %patch -p0

%build
    %{l_shtool} subst %{l_value -s -a} \
        poppler/GlobalParams.cc
    mkdir build
    cd build
    cmake \
        -DCMAKE_BUILD_TYPE="Release" \
        -DCMAKE_INSTALL_PREFIX="%{l_prefix}" \
        -DCMAKE_C_COMPILER="%{l_cc}" \
        -DCMAKE_C_FLAGS="%{l_cflags} %{l_cppflags cairo boost .} -Wno-cast-function-type" \
        -DCMAKE_CXX_COMPILER="%{l_cxx}" \
        -DCMAKE_CXX_FLAGS="%{l_cxxflags} %{l_cppflags boost cairo .} -Wno-cast-function-type" \
        -DCMAKE_EXE_LINKER_FLAGS="%{l_ldflags boost .}" \
        -DBUILD_SHARED_LIBS=off \
        -DCAIRO_INCLUDE_DIRS="%{l_prefix}/include/cairo:%{l_prefix}/include/boost:%{l_prefix}/include" \
        -DCAIRO_LIBRARIES="`pkg-config cairo --libs`" \
        -DCMAKE_CXX_STANDARD_LIBRARIES="-lpixman-1 -lzstd -lnghttp2 -lssl -lcrypto" \
        -DENABLE_BOOST=OFF \
        -DENABLE_LCMS=OFF \
        -DENABLE_NSS3=OFF \
        -DENABLE_QT5=OFF \
        -DENABLE_QT6=OFF \
%if "%{with_crypto}" == "yes"
        -DENABLE_GPGME=ON \
%else
        -DENABLE_GPGME=OFF \
%endif
        ..
    %{l_make} %{l_mflags -O}

%install
    (   cd build
        %{l_make} %{l_mflags} install DESTDIR=$RPM_BUILD_ROOT
    ) || exit $?
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/gtk-doc >/dev/null 2>&1 || true
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/include/poppler \
        $RPM_BUILD_ROOT%{l_prefix}/include/poppler/splash \
        $RPM_BUILD_ROOT%{l_prefix}/include/poppler/goo
    %{l_shtool} install -c -m 644 \
        poppler/*.h $RPM_BUILD_ROOT%{l_prefix}/include/poppler/
    %{l_shtool} install -c -m 644 \
        splash/*.h $RPM_BUILD_ROOT%{l_prefix}/include/poppler/splash/
    %{l_shtool} install -c -m 644 \
        goo/*.h $RPM_BUILD_ROOT%{l_prefix}/include/poppler/goo/
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

